# Spleen [![Build Status](https://travis-ci.org/Brightmd/Spleen.svg?branch=master)](https://travis-ci.org/Brightmd/Spleen)
A library of utilities for systems application development


## Running Tests

```
$ tox
```

##  Build/upload

```
$ python setup.py sdist bdist_wheel
$ twine upload dist/*
```

## Change Log

* 0.0.1:
  - Yo
